@@ -8,22 +8,34 @@ app = Typer()
 
 @app.command(help="Create a new project from a template.")
 def init():
+    def _clone_core_app(project_name: pathlib.Path):
+        core_app_url = "git@github.com:enabledu/enabled.git"
+        print(f"Cloning {core_app_url}...")
+        apps_directory = "." if pathlib.Path.cwd().name == "apps" else "./apps"
+        subprocess.run(
+            ["git", "clone", core_app_url, project_name / apps_directory / "enabled"]
+        )
+
     print("Creating new project...")
     template_url = "git@github.com:0xsirsaif/enabled-project-template.git"
     subprocess.run(["cookiecutter", template_url])
+    created_project_name = pathlib.Path.cwd()
+    _clone_core_app(created_project_name)
 
 
 @app.command(help="Clone an app repository from GitHub into apps directory.")
 def clone_app(app_url: str):
     """
-    Clone an app repository from GitHub into apps directory.
+    Clone an app repository from GitHub into apps directory. and install requirements.
     url: The url of the repository to clone.
     """
     print(f"Cloning {app_url}...")
+
     apps_directory = "." if pathlib.Path.cwd().name == "apps" else "./apps"
-    subprocess.run(
-        ["git", "clone", app_url, apps_directory + "/" + app_url.split("/")[-1]]
-    )
+    app_to_clone = app_url.split("/")[-1].replace(".git", "")
+
+    subprocess.run(["git", "clone", app_url, apps_directory + "/" + app_to_clone])
+    install_app(app_to_clone)
 
 
 @app.command(help="Remove an app from the apps directory.")
@@ -65,6 +77,16 @@ def install_app(app_name: str):
     app_name: The name of the app to install.
     """
     print(f"Installing {app_name}...")
+    cwd = pathlib.Path.cwd()
+    is_apps_besides = True if (cwd / "apps").exists() else False
+    if is_apps_besides:
+        requirements_file = cwd / "apps" / app_name / "requirements.txt"
+        if requirements_file.exists():
+            subprocess.run(["python", "-m", "pip", "install", "-r", requirements_file])
+    else:
+        print(
+            "No apps directory found. Make sure you are in the project root directory."
+        )
 
 
 @app.command()
